==> istio-model-v1alpha3-5.12.4-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TrafficPolicyBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TrafficPolicyBuilder extends io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluentImpl<io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy,io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder>{
  public TrafficPolicyBuilder() {
    this(false);
  }
  public TrafficPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new TrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy instance) {
    this(fluent, instance, false);
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConnectionPool(instance.getConnectionPool()); 
    fluent.withLoadBalancer(instance.getLoadBalancer()); 
    fluent.withOutlierDetection(instance.getOutlierDetection()); 
    fluent.withPortLevelSettings(instance.getPortLevelSettings()); 
    fluent.withTls(instance.getTls()); 
    this.validationEnabled = validationEnabled; 
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy instance) {
    this(instance,false);
  }
  public TrafficPolicyBuilder(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConnectionPool(instance.getConnectionPool()); 
    this.withLoadBalancer(instance.getLoadBalancer()); 
    this.withOutlierDetection(instance.getOutlierDetection()); 
    this.withPortLevelSettings(instance.getPortLevelSettings()); 
    this.withTls(instance.getTls()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy build() {
    TrafficPolicy buildable = new TrafficPolicy(fluent.getConnectionPool(),fluent.getLoadBalancer(),fluent.getOutlierDetection(),fluent.getPortLevelSettings(),fluent.getTls());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TrafficPolicyBuilder that = (TrafficPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TrafficPolicyBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TrafficPolicyBuilder extends TrafficPolicyFluentImpl<TrafficPolicyBuilder> implements VisitableBuilder<TrafficPolicy,TrafficPolicyBuilder>{
  public TrafficPolicyBuilder() {
    this(false);
  }
  public TrafficPolicyBuilder(Boolean validationEnabled) {
    this(new TrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyBuilder(TrafficPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TrafficPolicyBuilder(TrafficPolicyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyBuilder(TrafficPolicyFluent<?> fluent,TrafficPolicy instance) {
    this(fluent, instance, false);
  }
  public TrafficPolicyBuilder(TrafficPolicyFluent<?> fluent,TrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConnectionPool(instance.getConnectionPool()); 
    fluent.withLoadBalancer(instance.getLoadBalancer()); 
    fluent.withOutlierDetection(instance.getOutlierDetection()); 
    fluent.withPortLevelSettings(instance.getPortLevelSettings()); 
    fluent.withTls(instance.getTls()); 
    this.validationEnabled = validationEnabled; 
  }
  public TrafficPolicyBuilder(TrafficPolicy instance) {
    this(instance,false);
  }
  public TrafficPolicyBuilder(TrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConnectionPool(instance.getConnectionPool()); 
    this.withLoadBalancer(instance.getLoadBalancer()); 
    this.withOutlierDetection(instance.getOutlierDetection()); 
    this.withPortLevelSettings(instance.getPortLevelSettings()); 
    this.withTls(instance.getTls()); 
    this.validationEnabled = validationEnabled; 
  }
  TrafficPolicyFluent<?> fluent;
  Boolean validationEnabled;
  public TrafficPolicy build() {
    TrafficPolicy buildable = new TrafficPolicy(fluent.getConnectionPool(),fluent.getLoadBalancer(),fluent.getOutlierDetection(),fluent.getPortLevelSettings(),fluent.getTls());
    return buildable;
  }
  
}
